use std::path::PathBuf;
use std::num::NonZeroUsize;

#[derive(Debug, Clone, PartialEq, Eq)]
pub enum Recursion
{
    None,
    Limited(usize),
    Unlimited,
}

impl Default for Recursion
{
    #[inline]
    fn default() -> Self
    {
	Self::Unlimited
    }
}

impl Recursion
{
    /// Can we run at this depth?
    pub fn can_run(&self, depth: usize) -> bool
    {
	match self {
	    Self::None => depth == 1,
	    Self::Limited(limit) => depth <= *limit,
	    Self::Unlimited => true
	}
    }
}

/// Configuration for this run
#[derive(Debug, Clone, PartialEq, Eq, Default)]
pub struct Config
{
    pub paths: Vec<PathBuf>,
    pub recursive: Recursion,
    pub max_tasks: Option<NonZeroUsize>,
}
